@@ -8,7 +8,6 @@ import os
 import posixpath
 import fnmatch
 from pathlib import Path
-from pprint import pprint
 from datetime import datetime
 from textwrap import dedent
 
@@ -40,11 +39,7 @@ def get_token():
     print(msg)
 
     auth_code = input('Enter the authorization code here: ').strip()
-    try:
-        oauth_result = auth_flow.finish(auth_code)
-    except Exception as err:
-        print(f'Error: {err}')
-
+    oauth_result = auth_flow.finish(auth_code)
     token = oauth_result.access_token
 
     return token
@@ -121,7 +116,7 @@ def download_dropbox_file(dbx, dropbox_path, local_path):
 
 
 def normalise_path(path):
-    'Modify a path (str or Path) such that it is a Dropbox-compatible path string.'
+    """Modify a path (str or Path) such that it is a Dropbox-compatible path string."""
     path = posixpath.join(*str(path).split(os.path.sep))
     if not path.startswith('/'):
         path = '/' + path
